# Contact Actions

https://docs.aws.amazon.com/connect/latest/APIReference/contact-actions.html

Actions that manipulate contact data within flows running in the context of a contact.

## Implementation Status

| Block | Status | Notes |
|-------|--------|-------|
| CompleteOutboundCall | Not Implemented | |
| CreateCase | Not Implemented | |
| CreateTask | Implemented | Basic implementation |
| CreateWisdomSession | Not Implemented | |
| DequeueContactAndTransferToQueue | Not Implemented | |
| EndFlowModuleExecution | Not Implemented | |
| GetCase | Not Implemented | |
| InvokeFlowModule | Not Implemented | |
| ResumeContact | Not Implemented | |
| StartOutboundChatContact | Not Implemented | |
| TagContact | Not Implemented | |
| TransferContactToAgent | Not Implemented | |
| TransferContactToQueue | Implemented | Basic implementation |
| UnTagContact | Not Implemented | |
| UpdateCase | Not Implemented | |
| UpdateContactAttributes | Implemented | Basic implementation |
| UpdateContactCallbackNumber | Implemented | Basic implementation |
| UpdateContactData | Not Implemented | |
| UpdateContactEventHooks | Implemented | Basic implementation |
| UpdateContactMediaStreamingBehavior | Not Implemented | |
| UpdateContactRecordingBehavior | Implemented | Basic implementation |
| UpdateContactRoutingBehavior | Implemented | Basic implementation |
| UpdateContactTargetQueue | Implemented | Basic implementation |
| UpdateContactTextToSpeechVoice | Not Implemented | |
| UpdatePreviousContactParticipantState | Not Implemented | |

## Implemented: 8/25
